Index: trunk/xpressme_integration_kit/wp-content/plugins/xpressme/include/notify_functions.php
===================================================================
--- trunk/xpressme_integration_kit/wp-content/plugins/xpressme/include/notify_functions.php	(revision 338)
+++ trunk/xpressme_integration_kit/wp-content/plugins/xpressme/include/notify_functions.php	(revision 343)
@@ -49,8 +49,14 @@
 	}
 //	set_error_handler("xpress_error_handler");
-	require_once $xoops_config->xoops_mainfile_path;	// load XOOPS System
-	$module_id = get_xpress_modid() ;
-	$notification_handler =& xoops_gethandler( 'notification' ) ;
-	$notification_handler->triggerEvent($category, $item_id, $event, $extra_tags, $user_list, $module_id, $omit_user_id);
+	if ($xoops_config->is_impress != true){  // impress cms is error
+		if ( !defined("XOOPS_MAINFILE_INCLUDED")) {
+			require_once $xoops_config->xoops_mainfile_path;	// load XOOPS System
+		}
+	}
+	if ( defined("XOOPS_MAINFILE_INCLUDED")) {
+		$module_id = get_xpress_modid() ;
+		$notification_handler =& xoops_gethandler( 'notification' ) ;
+		$notification_handler->triggerEvent($category, $item_id, $event, $extra_tags, $user_list, $module_id, $omit_user_id);
+	}
 }
 
